<?php
// $Id: syntaxhighlighter.admin.inc,v 1.17 2010/09/29 22:49:54 mattyoung Exp $

/**
 * @file
 * Syntax highlighter module admin form
 *
 * Define the admin form
 */

/**
 * An admin form to specify which language to support for highlighting
 */
function syntaxhighlighter_settings_form() {
  // delete the variable to force a re-scan of library location just in case
  variable_del('syntaxhighlighter_lib_location');
  $path = _syntaxhighlighter_get_lib_location();

  $files = file_scan_directory($path .'/scripts', 'shBrush.*\.js');
  foreach ($files as $file) {
    $lang_options[$file->basename] = substr($file->name, 7);
  }
  ksort($lang_options);
  $form['syntaxhighlighter_enabled_languages'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Enabled languages'),
    '#options' => $lang_options,
    '#default_value' => variable_get('syntaxhighlighter_enabled_languages', array('shBrushPhp.js')),
    '#description' => t('Only the selected languages will be enabled and its corresponding required Javascript files loaded.  If you enable "Use autoloader below, then the brushes are dynamically loaded.'),
    '#multicolumn' => array('width' => 3),
    '#checkall' => TRUE,
  );

  $form['syntaxhighlighter_use_autoloader'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use autoloader'),
    '#default_value' => variable_get('syntaxhighlighter_use_autoloader', FALSE),
  );

  $files = file_scan_directory($path .'/styles', 'shTheme.*\.css', array('.', '..', 'CVS', 'shThemeDefault.css'));
  foreach ($files as $file) {
    $theme_options[$file->basename] = substr($file->name, 7);
  }
  ksort($theme_options);
  $theme_options = array_merge(array('shThemeDefault.css' => 'Default'), $theme_options);
  $form['syntaxhighlighter_theme'] = array(
    '#type' => 'radios',
    '#title' => t('Theme'),
    '#description' => t('Choose a syntax highlight theme.'),
    '#options' => $theme_options,
    '#default_value' => variable_get('syntaxhighlighter_theme', 'shThemeDefault.css'),
    '#multicolumn' => array('width' => 2),
  );

  $form['syntaxhighlighter_tagname'] = array(
    '#type' => 'textfield',
    '#title' => t('Tag name'),
    '#description' => t('Use different tag to markup code.'),
    '#default_value' => variable_get('syntaxhighlighter_tagname', 'pre'),
    '#size' => 10,
  );
  $form['syntaxhighlighter_legacy_mode'] = array(
    '#type' => 'radios',
    '#title' => t('Legacy mode'),
    '#description' => t('Enable pre-2.0 style markup support.'),
    '#options' => array(t('Disabled'), t('Enabled')),
    '#default_value' => variable_get('syntaxhighlighter_legacy_mode', 0),
  );

    // Fix a javascript compability issue with imce reported by gmark
    // Don't inject syntax highlighter javascript on "off pages"
  $form['syntaxhighlighter_off_pages'] = array(
    '#type' => 'textarea',
    '#title' => t('Turn off Syntax Highlighter on these pages'),
    '#default_value' => variable_get('syntaxhighlighter_off_pages', "admin\nadmin/*\nuser\nuser/*\nimce\nimce/*\n"),
    '#description' => t("Enter one page per line as Drupal paths. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", array('%blog' => 'blog', '%blog-wildcard' => 'blog/*', '%front' => '<front>')),
  );

  $form['syntaxhighlighter_default_expressions'] = array(
    '#type' => 'textarea',
    '#title' => t('Default expressions'),
    '#default_value' => variable_get('syntaxhighlighter_default_expressions', ''),
    '#description' => t('Enter syntaxhihglighter default settings javascript expressions, e.g. !example. To turn off clipboardSwf, use !swfoff. See the <a href="!link">syntaxhighlighter js lib doc page</a> for details. Note: these default settings affect the entire site unless they are overridden locally.',
                         array('!example' => '<code>SyntaxHighlighter.defaults[\'auto-links\'] = true;SyntaxHighlighter.defaults[\'gutter\'] = false;</code>',
                               '!swfoff' => '<code>SyntaxHighlighter.config.clipboardSwf = undefined;</code>',
                               '!link' => 'http://alexgorbatchev.com/wiki/SyntaxHighlighter:Configuration',
                         )),
  );

  $form['#submit'][] = 'syntaxhighlighter_settings_form_submit';

  return system_settings_form($form);
}


function syntaxhighlighter_settings_form_submit($form, &$form_state) {
  $path = file_directory_path() . '/syntaxhighlighter.autoloader.js';
  if ($form_state['values']['syntaxhighlighter_use_autoloader']) {
    $script_path = '/' . _syntaxhighlighter_get_lib_location() . '/scripts/';
    $script_data = <<<HEREHERE
/*
 * This file is generated by the Syntaxhighlighter module
 */
HEREHERE;
    $script_data .= "\nfunction syntaxhighlighterAutoloaderSetup() {\n  SyntaxHighlighter.autoloader(\n";
    $need_ending = FALSE;
    $brushes = &$form_state['values']['syntaxhighlighter_enabled_languages'];
    foreach ($brushes as $b) {
      if ($b) {
        if ($need_ending) {
          $script_data .= ",\n";
        }
        $alias = strtolower(substr(substr($b, 7), 0, -3));
        $script_data .= "    '$alias $script_path$b'";
        $need_ending = TRUE;
      }
    }
    $script_data .= "\n);\n}\n";
    file_save_data($script_data, $path, FILE_EXISTS_REPLACE);
  }
  else {
    file_delete($path);
  }
}
